chrome.contextMenus.onClicked.addListener(addToStammTVHandler);

chrome.runtime.onInstalled.addListener(function (details) {
    if (details.reason === "install") {
        chrome.runtime.openOptionsPage();
    } else if (details.reason === "update") {
        chrome.storage.local.get(['baseURL', 'wssURL'], function (items) {
            if (items.wssURL !== undefined && items.wssURL.startsWith('wss://')) {
            } else {
                chrome.runtime.openOptionsPage();
            }
        });
    }
})

const CONTEXT_MENU_ID = "STAMMTV_ADD_URL_TO_PLAYLIST";

chrome.contextMenus.removeAll(function () {
    chrome.contextMenus.create({
        title: "Zu StammTV Playlist hinzufügen...",
        contexts: ["link"],
        id: CONTEXT_MENU_ID
    });
});

function parseYoutubeURL(url) {
    const YOUTUBE_URL_REGEX = /^https?:\/\/(?:www\.)?youtu(?:\.be\/|be\.com\/watch\?v=|be\.com\/shorts\/)([^#&?]*)(?:[?&]t=\d+)?.*/;

    let match = url.match(YOUTUBE_URL_REGEX);
    return (match && match[1].length === 11) ? match[1] : false;
}


function addToStammTVHandler(info, tab) {
    if (info.menuItemId === CONTEXT_MENU_ID) { //if OUR menu item was clicked
        console.log('clicked!');

        let videoId = parseYoutubeURL(info.linkUrl);
        if (videoId) {
            let websocket;
            chrome.storage.local.get('wssURL', function (result) {
                if (result.wssURL) {
                    websocket = new WebSocket(result.wssURL);

                    const playerReady = {"type": "playerReady"};
                    const setVideo = {type: "setVideo", video: videoId,};

                    websocket.onopen = function () {
                        console.log('[open] Connection established');

                        websocket.send(JSON.stringify(playerReady));
                        websocket.send(JSON.stringify(setVideo));

                        setTimeout(() => websocket.close(), 5000);
                    };

                    websocket.onmessage = function (event) {
                        console.log(`[message] Data received from server: ${event.data}`);
                    };

                    websocket.onclose = function (event) {
                        if (event.wasClean) {
                            console.log(`[close] Connection closed cleanly, code=${event.code} reason=${event.reason}`)
                        } else {
                            console.log('[close] Connection died');
                        }
                    }

                    websocket.onerror = function (error) {
                        alert(`[error] ${error.message}`);
                    };
                } else {
                    chrome.runtime.openOptionsPage();
                }
            });
        } else {
            console.error('failed to add ' + info.linkurl + ': o(一︿一+)o not a valid link');
        }
    }
}
